@@ -20,8 +20,12 @@ set -e
 
 case "$1" in
     configure)
+    if [ -x "/etc/init.d/benno-smtp" ]; then
+        update-rc.d benno-smtp defaults >/dev/null
+        set +e
+        /etc/init.d/benno-smtp start
+    fi
     ;;
-
     abort-upgrade|abort-remove|abort-deconfigure)
     ;;
 
@@ -32,6 +36,6 @@ case "$1" in
 esac
 
 
-perl -p -i -e 's/BENNOCOREDIR=\/opt\/benno/BENNOCOREDIR=\/opt\/benno-smtp/' /etc/init.d/benno-smtp
+perl -p -i -e 's/^BENNOCOREDIR=\/opt\/benno$/BENNOCOREDIR=\/opt\/benno-smtp/' /etc/init.d/benno-smtp
 
 exit 0
