@@ -1,7 +1,7 @@
 #!/bin/sh
 set -e
 # Automatically added by dh_installinit
-if [ -x "/etc/init.d/benno-smtp" ]; then
+if [ -x "/etc/init.d/benno-smtp" ] && [ "$1" = remove ]; then
 	invoke-rc.d benno-smtp stop || exit $?
 fi
 # End automatically added section
